@@ -23,7 +23,7 @@
 #ifndef MINUET_IUICONTROLLER_H
 #define MINUET_IUICONTROLLER_H
 
-#include "minuetinterfacesexport.h"
+#include <interfaces/minuetinterfacesexport.h>
 
 #include <QObject>
 
@@ -35,7 +35,9 @@ class MINUETINTERFACES_EXPORT IUiController : public QObject
     Q_OBJECT
 
 public:
-    ~IUiController() override;
+    virtual ~IUiController() override;
+    
+    virtual QString errorString() const = 0;
 
 protected:
     explicit IUiController(QObject *parent = 0);
